@@ -10,7 +10,7 @@
 # You can redistribute it and/or modify it under the terms of the
 # GPL2, GNU General Public License version 2.
 #
-# $Id: Config.pm,v 1.5 2005/10/02 14:10:02 mumumu-org Exp $
+# $Id: Config.pm,v 1.7 2005/10/07 16:38:30 mumumu-org Exp $
 #
 
 use strict;
@@ -28,7 +28,7 @@ package RSS2IMAPLIB::Config;
 
     our $this = undef;
 
-    our $VERSION = "0.70(20051002)";
+    our $VERSION = "0.71(20051008)";
 
     #    Global config filename.
     our $GLOBAL_CONFIG_FILE     = "conf/rss2imap.conf";
@@ -56,10 +56,10 @@ package RSS2IMAPLIB::Config;
         'subject'       => '%{item:title}',
         'from'          => $ENV{'USER'}.'@'
                           .($ENV{'HOSTNAME'} ? $ENV{'HOSTNAME'} : "localhost"),
-        'expire-unseen' => 'no',
+        'expire-unseen' => undef,
         'expire'        => -1,
         'expire-folder' => undef,
-        'sync'          => 'no',
+        'sync'          => undef,
     };
 
 
@@ -443,7 +443,7 @@ package RSS2IMAPLIB::Config;
             my ($config_key, $value ) = split /=/, $line;
             $config_key = &__trim( $config_key );
             $value      = &__trim( $value );
-            $value = undef  if ($value eq "undef" || $value eq "" );
+            $value = undef if ($value eq "undef" || $value eq "" || $value eq "no" );
             $return_hash{$config_key} = $value;
         }
 
