@@ -11,7 +11,7 @@
 # You can redistribute it and/or modify it under the terms of the
 # GPL2, GNU General Public License version 2.
 #
-# $Id: Rss2imap.pm,v 1.3 2005/10/02 11:55:42 mumumu-org Exp $
+# $Id: Rss2imap.pm,v 1.5 2005/10/07 16:19:51 mumumu-org Exp $
 #
 
 require 5.008_000;
@@ -399,6 +399,8 @@ BODY
         my $to         = $this->{site_config}->{to};
         my $message_id = $this->gen_message_id ($rss, $item);
         ($subject, $from) = $this->apply_template ($rss, $item, undef, $subject, $from);
+        # if line feed character include, some mailer make header broken.. :<
+        $subject =~ s/\n//g;
 
         my $m_from    = RSS2IMAPLIB::Unicode::to_mime ($from);
         my $m_subject = RSS2IMAPLIB::Unicode::to_mime ($subject);
@@ -453,14 +455,10 @@ BODY
         $subject =~ s/\n//g;
         $item->{link} =~ s/\n//g;
 
-        my $return_text_body = <<"TEXT_BODY"
-[ Title ] : $subject
+        my $return_text_body = "[ Title ] : $subject\n\n";
+        $return_text_body .= "$desc\n\n" if ($desc);
+        $return_text_body .= "[ Complete Story ] : $item->{link}";
 
-$desc
-
-[ Complete Story ] : $item->{link}
-TEXT_BODY
-;
         return $return_text_body;
 
     }
@@ -656,12 +654,12 @@ BODY
         my @result;
         for my $from (@from) {
             if ($from) {
-            for my $key (keys %cnf) {
-                next unless ($cnf{$key});
-                $cnf{$key} =~ s/\./:/g if ($folder_flg);
-                my $key2 = "%{" . $key . "}";
-                $from =~ s/$key2/$cnf{$key}/eg;
-            }
+                for my $key (keys %cnf) {
+                    next unless ($cnf{$key});
+                    $cnf{$key} =~ s/\./:/g if ($folder_flg);
+                    my $key2 = "%{" . $key . "}";
+                    $from =~ s/$key2/$cnf{$key}/eg;
+                }
             }
             push @result, $from;
         }
@@ -670,4 +668,4 @@ BODY
     }
 }
 
-1;
\ No newline at end of file
+1;
